@@ -3,25 +3,29 @@ from django.db import models
 from jmbo.models import ModelBase
 from preferences.models import Preferences
 
+
 class Banner(ModelBase):
     pass
 
+
 class CodeBanner(Banner):
     code = models.TextField(
-        help_text='The full HTML/Javascript code snippet to be embedded for this banner.'
+        help_text='The full HTML/Javascript code snippet to be \
+embedded for this banner.'
     )
-    
+
     class Meta():
         verbose_name = 'Code banner'
         verbose_name_plural = 'Code banners'
 
+
 class ImageBanner(Banner):
     url = models.CharField(
-        max_length='256', 
-        verbose_name='URL', 
+        max_length='256',
+        verbose_name='URL',
         help_text='URL (internal or external) to which this banner will link.'
     )
-    
+
     class Meta():
         verbose_name = 'Image banner'
         verbose_name_plural = 'Image banners'
@@ -29,6 +33,7 @@ class ImageBanner(Banner):
     def get_absolute_url(self):
         return self.url
 
+
 class BannerPreferences(Preferences):
     __module__ = 'preferences.models'
 
@@ -36,6 +41,7 @@ class BannerPreferences(Preferences):
         verbose_name = 'Banner preferences'
         verbose_name_plural = 'Banner preferences'
 
+
 class BannerOption(models.Model):
     banner_preferences = models.ForeignKey('preferences.BannerPreferences')
     is_default = models.BooleanField(
